import json
import unittest
from unittest.mock import patch
import urllib3

from aihub.api.jobs_api import JobsApi


class TestJobsApi(unittest.TestCase):
  """JobsApi unit test stubs"""

  def setUp(self) -> None:
    self.api = JobsApi()

  def tearDown(self) -> None:
    pass

  @patch.object(urllib3.PoolManager, 'request')
  def test_status(self, mock_request) -> None:
    """Test case for status

        Poll the status of asynchronous jobs.
        """
    job_id = "abc123"
    expected_response = {
        "state": "COMPLETE",
        "message": "Job completed successfully"
    }

    # Mock the HTTP GET request response
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.job_status(job_id)
    mock_request.assert_called_once()

    # Assert
    self.assertEqual(response.state, expected_response['state'])
    self.assertEqual(response.message, expected_response['message'])



# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr
from pydantic import Field
from aihub.models.run_deployment_request_settings import RunDeploymentRequestSettings
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class RunDeploymentRequest(BaseModel):
    """
    RunDeploymentRequest
    """ # noqa: E501
    batch_id: Optional[StrictInt] = Field(default=None, description="Required unless using `input_dir` or `manual_upstream_integration`. The batch ID of a batch created with the [Batches endpoint](/api-sdk/api-reference/batches/create-batch/). All files uploaded to the batch are used as input for the run.")
    input_dir: Optional[StrictInt] = Field(default=None, description="Required unless using `batch_id` or `manual_upstream_integration`. The path of the input folder in a connected drive or Instabase Drive. See [Specifying file paths](/api-sdk/api-reference/run-reference#specifying-file-paths).")
    manual_upstream_integration: Optional[StrictBool] = Field(default=None, description="Use the deployment's upstream integration as a source rather than a `batch_id` or `input_dir`. Requires an upstream integration to be configured for the deployment.")
    from_timestamp: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Required if `manual_upstream_integration` is true and the upstream integration is a mailbox integration. Specifies the earliest date in Unix time milliseconds from which to pull emails.")
    to_timestamp: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Required if `manual_upstream_integration` is true and the upstream integration is a mailbox integration. Specifies the latest date in Unix time milliseconds from which to pull emails.")
    version: Optional[StrictStr] = Field(default=None, description="Version of the app to use. If not specified, defaults to the latest production version.")
    output_workspace: Optional[StrictStr] = Field(default=None, description="The workspace in which to run the app. The output is saved to the default drive of the specified workspace. If not defined, the default is:  - **Community accounts**: Runs in and saves to the personal workspace's Instabase Drive (`<USER-ID>/my-repo/Instabase Drive`).  - **Organization accounts**: Runs in and saves to the organization's default drive (`<ORGANIZATION-ID>/<USER-ID>/<default-drive>`). ")
    output_dir: Optional[StrictStr] = Field(default=None, description="Defines a specific location for the output to be saved in a connected drive or Instabase Drive. If defined, overrides the `output_workspace` value. See [Specifying file paths](/api-sdk/api-reference/run-reference#specifying-file-paths).")
    settings: Optional[RunDeploymentRequestSettings] = None
    __properties: ClassVar[List[str]] = ["batch_id", "input_dir", "manual_upstream_integration", "from_timestamp", "to_timestamp", "version", "output_workspace", "output_dir", "settings"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunDeploymentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RunDeploymentRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "batch_id": obj.get("batch_id"),
            "input_dir": obj.get("input_dir"),
            "manual_upstream_integration": obj.get("manual_upstream_integration"),
            "from_timestamp": obj.get("from_timestamp"),
            "to_timestamp": obj.get("to_timestamp"),
            "version": obj.get("version"),
            "output_workspace": obj.get("output_workspace"),
            "output_dir": obj.get("output_dir"),
            "settings": RunDeploymentRequestSettings.from_dict(obj.get("settings")) if obj.get("settings") is not None else None
        })
        return _obj





import json
import unittest
from unittest.mock import patch, mock_open
import urllib3

from aihub.api.conversations_api import ConversationsApi
from aihub.models import Conversation, DocumentUploadResponse, PromptResponse


class TestConversationsApi(unittest.TestCase):
  """ConversationsApi unit test stubs"""

  def setUp(self) -> None:
    self.api = ConversationsApi()

  def tearDown(self) -> None:
    pass

  @patch(
      'builtins.open', new_callable=mock_open, read_data='DUMMY FILE CONTENT')
  @patch.object(urllib3.PoolManager, 'request')
  def test_add_documents_to_conversation(self, mock_request,
                                         mock_file_open) -> None:
    """Test case for add_documents_to_conversation

        Upload documents to a specified conversation.
        """
    conversation_id = "123"
    files = ['doc1.pdf', 'doc2.pdf']  # Simulating file names
    expected_response = {
        "upload_status": {
            "success": [{
                "name": "doc1.pdf"
            }],
            "failure": [{
                "name": "doc2.pdf",
                "reason": "File too large"
            }]
        }
    }
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=201)
    mock_request.return_value = mock_response

    response = self.api.add_documents_to_conversation(conversation_id, files)
    self.assertEqual(len(response.upload_status.success), 1)
    self.assertEqual(len(response.upload_status.failure), 1)

  @patch.object(urllib3.PoolManager, 'request')
  def test_converse(self, mock_request) -> None:
    """Test case for converse

        Converse with the documents in a conversation.
        """
    conversation_id = "123"
    question = "What is the main topic?"
    document_ids = [
        1, 2
    ]  # Assuming these are IDs of documents in the conversation
    expected_response = {
        "prompt_id": "abc123",
        "answer": "The main topic is machine learning."
    }

    # Mock the HTTP POST request response
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    # Act
    response = self.api.converse(conversation_id, {
        'question': question,
        'document_ids': document_ids,
        'mode': 'default'
    })

    # Assert
    actual_method, actual_url = mock_request.call_args[0][
        0], mock_request.call_args[0][1]
    self.assertEqual(actual_method, 'POST')
    self.assertIn(
        conversation_id,
        actual_url)  # Ensure the conversation_id is part of the URL path

    # Verify that the response is correctly interpreted
    self.assertEqual(response.prompt_id, expected_response["prompt_id"])
    self.assertEqual(response.answer, expected_response["answer"])

    response = self.api.converse(conversation_id, {
        'question': question,
        'document_ids': document_ids,
        'mode': 'advanced'
    })

    # Assert
    actual_method, actual_url = mock_request.call_args[0][
        0], mock_request.call_args[0][1]
    self.assertEqual(actual_method, 'POST')
    self.assertIn(
        conversation_id,
        actual_url)  # Ensure the conversation_id is part of the URL path

    # Verify that the response is correctly interpreted
    self.assertEqual(response.prompt_id, expected_response["prompt_id"])
    self.assertEqual(response.answer, expected_response["answer"])

  @patch('builtins.open', new_callable=mock_open, read_data='FILE CONTENT')
  @patch.object(urllib3.PoolManager, 'request')
  def test_create_conversation(self, mock_request, mock_file_open) -> None:
    """Test case for create_conversation

        Create a new conversation and upload files.
        """
    expected_response = {
        "id": "123",
        "name": "Test Conversation",
        "upload_status": {
            "success": [{
                "name": "file1.txt"
            }],
            "failure": []
        }
    }
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=201)
    mock_request.return_value = mock_response

    response = self.api.create_conversation(
        name="Test Conversation", files=["file1.txt"])
    self.assertEqual(response.id, expected_response["id"])
    self.assertEqual(response.name, expected_response["name"])
    self.assertTrue(len(response.upload_status.success) > 0)

  @patch.object(urllib3.PoolManager, 'request')
  def test_delete_documents_from_conversation(self, mock_request) -> None:
    """Test case for delete_documents_from_conversation

        Deletes specified documents from a conversation.
        """
    conversation_id = "123"
    document_ids = [456, 789]

    # Mock the HTTP DELETE request response
    mock_response = urllib3.HTTPResponse(body=b' ', status=204)
    mock_request.return_value = mock_response

    self.api.delete_documents_from_conversation(
        conversation_id, ids=document_ids)
    mock_request.assert_called_once()

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_conversation(self, mock_request) -> None:
    """Test case for get_conversation

        Get the details of the conversation.
        """
    conversation_id = "123"
    expected_response = {
        "id":
        "123",
        "name":
        "Test Conversation",
        "description":
        "",
        "state":
        "COMPLETE",
        "documents": [{
            "id": 456,
            "name": "file1.txt",
            "state": "PROCESSED",
            "uploadTimestamp": None
        }],
    }
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.get_conversation(conversation_id)
    self.assertEqual(response.id, expected_response["id"])

  @patch.object(urllib3.PoolManager, 'request')
  def test_get_conversation_document_metadata(self, mock_request) -> None:
    """Test case for get_conversation_document_metadata

        Retrieve metadata for a specified document within a conversation.
        """
    conversation_id = "123"
    document_id = 456
    expected_response = {
        "id": document_id,
        "name": "doc1.pdf",
        "ibdoc_path": "ibuser/my-repo/doc1.pdf",
        "additional_metadata": {}
    }
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.get_conversation_document_metadata(
        conversation_id, document_id)
    self.assertEqual(response.id, expected_response["id"])
    self.assertEqual(response.name, expected_response["name"])

  @patch.object(urllib3.PoolManager, 'request')
  def test_list_conversations(self, mock_request) -> None:
    """Test case for list_conversations

        List all conversations created.
        """
    expected_response = {
        "conversations": [{
            "id": "123",
            "name": "Test Conversation"
        }]
    }
    mock_response = urllib3.HTTPResponse(
        body=bytes(json.dumps(expected_response), 'utf-8'), status=200)
    mock_request.return_value = mock_response

    response = self.api.list_conversations()
    self.assertTrue(len(response.conversations) > 0)
    self.assertEqual(response.conversations[0].id,
                     expected_response["conversations"][0]["id"])

  @patch.object(urllib3.PoolManager, 'request')
  def test_delete_conversation(self, mock_request) -> None:
    """Test case for delete_conversation

        Delete the requested conversation.
        """
    conversation_id = "123"
    mock_response = urllib3.HTTPResponse(body=b' ', status=204)
    mock_request.return_value = mock_response

    response = self.api.delete_conversation(conversation_id)

    # Assert
    actual_method, actual_url = mock_request.call_args[0][
        0], mock_request.call_args[0][1]
    self.assertEqual(actual_method, 'DELETE')
    self.assertIn(
        conversation_id,
        actual_url)  # Ensure the conversation_id is part of the URL path
    mock_request.assert_called_once()


if __name__ == '__main__':
  unittest.main()



# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. Please see https://docs.instabase.com for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
from aihub.models.run_query_request_source_app import RunQueryRequestSourceApp
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class RunQueryRequest(BaseModel):
    """
    RunQueryRequest
    """ # noqa: E501
    query: StrictStr = Field(description="Your query for the source app. <Tip> Queries made by API are also visible in your query history when accessing the source app from the AI Hub user interface.</Tip>")
    model_name: Optional[StrictStr] = Field(default='multistep-lite', description="The model to use to answer the query. Supports the multistep model (`multistep-lite`) and research mode (`multistep`), a more powerful but slower variant of the multistep model that's suited to complex reasoning queries. See [Choosing a model](/overview/models/) for details.")
    include_source_info: Optional[StrictBool] = Field(default=False, description="Set to true to return information about the source documents referenced when generating the query response. <Note> The multistep model (`model` set to `multistep-lite`) supports document-level source information. Research mode (`model` set to `multistep`) supports page-level source information.</Note>")
    source_app: RunQueryRequestSourceApp
    __properties: ClassVar[List[str]] = ["query", "model_name", "include_source_info", "source_app"]

    @field_validator('model_name')
    def model_name_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('multistep', 'multistep-lite'):
            raise ValueError("must be one of enum values ('multistep', 'multistep-lite')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": ()
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunQueryRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_app
        if self.source_app:
            _dict['source_app'] = self.source_app.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RunQueryRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "query": obj.get("query"),
            "model_name": obj.get("model_name") if obj.get("model_name") is not None else 'multistep-lite',
            "include_source_info": obj.get("include_source_info") if obj.get("include_source_info") is not None else False,
            "source_app": RunQueryRequestSourceApp.from_dict(obj.get("source_app")) if obj.get("source_app") is not None else None
        })
        return _obj





# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from pydantic import Field
from aihub.models.run_app_request_settings import RunAppRequestSettings
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class RunAppRequest(BaseModel):
    """
    RunAppRequest
    """ # noqa: E501
    app_name: Optional[StrictStr] = Field(default=None, description="Required unless using `app_id`. The name of the AI Hub app to run.")
    app_id: Optional[StrictStr] = Field(default=None, description="Required unless using `app_name`. The app ID of the AI Hub app to run.  <Tip>You can find an app ID in the app URL, such as http<span>s://</span>aihub.instabase.com/hub/apps/**528c36e8-ac5b-490d-a41b-7eec9c404b87**.</Tip> ")
    owner: Optional[StrictStr] = Field(default=None, description="The account that generated the app. If not specified, defaults to your AI Hub username.  For custom AI Hub apps belonging to you, accept the default. For public AI Hub apps published by Instabase, specify `instabase`. ")
    batch_id: Optional[StrictInt] = Field(default=None, description="Required unless using `input_dir`. The batch ID of a batch created with the [Batches endpoint.](/api-sdk/api-reference/batches/create-batch/) All files uploaded to the batch are used as input for the run.")
    input_dir: Optional[StrictStr] = Field(default=None, description="Required unless using `batch_id`. The path of the input folder in a connected drive or Instabase Drive. See [Specifying file paths.](/api-sdk/api-reference/run-reference#specifying-file-paths)")
    version: Optional[StrictStr] = Field(default=None, description="Version of the app to use. If not specified, defaults to the latest production version.")
    output_workspace: Optional[StrictStr] = Field(default=None, description="The workspace in which to run the app. The output is saved to the default drive of the specified workspace. If not defined, the default is:  - **Community accounts**: Runs in and saves to the personal workspace's Instabase Drive (`<USER-ID>/my-repo/Instabase Drive`).  - **Organization accounts**: Runs in and saves to the organization's default drive (`<ORGANIZATION-ID>/<USER-ID>/<default-drive>`). ")
    output_dir: Optional[StrictStr] = Field(default=None, description="Defines a specific location for the output to be saved in a connected drive or Instabase Drive. If defined, overrides the `output_workspace` value. See [Specifying file paths.](/api-sdk/run-reference/#specifying-file-paths)")
    settings: Optional[RunAppRequestSettings] = None
    __properties: ClassVar[List[str]] = ["app_name", "app_id", "owner", "batch_id", "input_dir", "version", "output_workspace", "output_dir", "settings"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunAppRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of RunAppRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "app_name": obj.get("app_name"),
            "app_id": obj.get("app_id"),
            "owner": obj.get("owner"),
            "batch_id": obj.get("batch_id"),
            "input_dir": obj.get("input_dir"),
            "version": obj.get("version"),
            "output_workspace": obj.get("output_workspace"),
            "output_dir": obj.get("output_dir"),
            "settings": RunAppRequestSettings.from_dict(obj.get("settings")) if obj.get("settings") is not None else None
        })
        return _obj





import unittest
from unittest.mock import patch
import urllib3

from aihub.api.files_api import FilesApi


class TestFilesApi(unittest.TestCase):
  """FilesApi unit test stubs"""

  def setUp(self) -> None:
    self.api = FilesApi()

  def tearDown(self) -> None:
    pass

  @patch.object(urllib3.PoolManager, 'request')
  def test_read_file(self, mock_request) -> None:
    """Test case for read_file

        Read file.
        """
    path = 'john.aihub-internal_instabase.com/my-repo/fs/Instabase Drive/files/foo.txt'

    # Mock the HTTP PUT request response
    file_contents = b'test'
    mock_response = urllib3.HTTPResponse(body=file_contents, status=200)
    mock_request.return_value = mock_response

    # Act
    response = self.api.read_file(path, expect_node_type='file')
    mock_request.assert_called_once()
    assert response == file_contents

  @patch.object(urllib3.PoolManager, 'request')
  def test_read_file_partial(self, mock_request) -> None:
    """Test case for read_file

        Read file.
        """
    path = 'john.aihub-internal_instabase.com/my-repo/fs/Instabase Drive/files/foo.txt'

    # Mock the HTTP PUT request response
    file_contents = b'test'
    mock_response = urllib3.HTTPResponse(body=file_contents[0:3], status=206)
    mock_request.return_value = mock_response

    # Act
    response = self.api.read_file(
        path, expect_node_type='file', range='bytes=0-2')
    mock_request.assert_called_once()
    assert response == file_contents[0:3]



# coding: utf-8

"""
    AI Hub API

    The AI Hub REST API. See https://docs.instabase.com/api-sdk/ for more details.

    The version of the OpenAPI document: 0.1
    Contact: support@instabase.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from pydantic import StrictBool, StrictInt, StrictStr, field_validator

from typing import List, Optional

from aihub.models.delete_run202_response import DeleteRun202Response
from aihub.models.list_runs200_response import ListRuns200Response
from aihub.models.results_response import ResultsResponse
from aihub.models.run import Run
from aihub.models.run_app_request import RunAppRequest
from aihub.models.run_deployment_request import RunDeploymentRequest

from aihub.api_client import ApiClient
from aihub.api_response import ApiResponse
from aihub.rest import RESTResponseType


class RunsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_run(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        delete_db_data: Annotated[Optional[StrictBool], Field(description="Delete the run's database data.")] = None,
        delete_input: Annotated[Optional[StrictBool], Field(description="Delete the run's input files.")] = None,
        delete_output: Annotated[Optional[StrictBool], Field(description="Delete the run's output files.")] = None,
        delete_logs: Annotated[Optional[StrictBool], Field(description="Delete the run's logs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DeleteRun202Response:
        """Delete run

        Deletes a specified run and optionally its associated database data, input files, output files, and logs. This is an asynchronous operation that must be [checked for completion.](/api-sdk/api-reference/jobs/job-status)

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param delete_db_data: Delete the run's database data.
        :type delete_db_data: bool
        :param delete_input: Delete the run's input files.
        :type delete_input: bool
        :param delete_output: Delete the run's output files.
        :type delete_output: bool
        :param delete_logs: Delete the run's logs.
        :type delete_logs: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_run_serialize(
            run_id=run_id,
            ib_context=ib_context,
            delete_db_data=delete_db_data,
            delete_input=delete_input,
            delete_output=delete_output,
            delete_logs=delete_logs,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DeleteRun202Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_run_with_http_info(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        delete_db_data: Annotated[Optional[StrictBool], Field(description="Delete the run's database data.")] = None,
        delete_input: Annotated[Optional[StrictBool], Field(description="Delete the run's input files.")] = None,
        delete_output: Annotated[Optional[StrictBool], Field(description="Delete the run's output files.")] = None,
        delete_logs: Annotated[Optional[StrictBool], Field(description="Delete the run's logs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DeleteRun202Response]:
        """Delete run

        Deletes a specified run and optionally its associated database data, input files, output files, and logs. This is an asynchronous operation that must be [checked for completion.](/api-sdk/api-reference/jobs/job-status)

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param delete_db_data: Delete the run's database data.
        :type delete_db_data: bool
        :param delete_input: Delete the run's input files.
        :type delete_input: bool
        :param delete_output: Delete the run's output files.
        :type delete_output: bool
        :param delete_logs: Delete the run's logs.
        :type delete_logs: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_run_serialize(
            run_id=run_id,
            ib_context=ib_context,
            delete_db_data=delete_db_data,
            delete_input=delete_input,
            delete_output=delete_output,
            delete_logs=delete_logs,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DeleteRun202Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_run_without_preload_content(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        delete_db_data: Annotated[Optional[StrictBool], Field(description="Delete the run's database data.")] = None,
        delete_input: Annotated[Optional[StrictBool], Field(description="Delete the run's input files.")] = None,
        delete_output: Annotated[Optional[StrictBool], Field(description="Delete the run's output files.")] = None,
        delete_logs: Annotated[Optional[StrictBool], Field(description="Delete the run's logs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete run

        Deletes a specified run and optionally its associated database data, input files, output files, and logs. This is an asynchronous operation that must be [checked for completion.](/api-sdk/api-reference/jobs/job-status)

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param delete_db_data: Delete the run's database data.
        :type delete_db_data: bool
        :param delete_input: Delete the run's input files.
        :type delete_input: bool
        :param delete_output: Delete the run's output files.
        :type delete_output: bool
        :param delete_logs: Delete the run's logs.
        :type delete_logs: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_run_serialize(
            run_id=run_id,
            ib_context=ib_context,
            delete_db_data=delete_db_data,
            delete_input=delete_input,
            delete_output=delete_output,
            delete_logs=delete_logs,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DeleteRun202Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_run_serialize(
        self,
        run_id,
        ib_context,
        delete_db_data,
        delete_input,
        delete_output,
        delete_logs,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        if delete_db_data is not None:
            
            _query_params.append(('delete_db_data', delete_db_data))
            
        if delete_input is not None:
            
            _query_params.append(('delete_input', delete_input))
            
        if delete_output is not None:
            
            _query_params.append(('delete_output', delete_output))
            
        if delete_logs is not None:
            
            _query_params.append(('delete_logs', delete_logs))
            
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/v2/apps/runs/{run_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_run_results(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        include_review_results: Annotated[Optional[StrictBool], Field(description="Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> ")] = None,
        include_confidence_scores: Annotated[Optional[StrictBool], Field(description="Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. ")] = None,
        include_validation_results: Annotated[Optional[StrictBool], Field(description="Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. ")] = None,
        include_source_info: Annotated[Optional[StrictBool], Field(description="Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. ")] = None,
        file_offset: Annotated[Optional[StrictInt], Field(description="The initial file index to start returning results from. Defaults to `0`.")] = None,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResultsResponse:
        """Get run results

        Get the results of a completed run.  <Info>  This API operation might return field names that differ from those in the Build project.  The operation converts field names to valid Python variable names by:  * Allowing only letters, numbers, and underscores * Requiring names to start with a letter or underscore * Replacing invalid characters with underscores * Converting single underscores to double underscores  Examples: * `due date` → `due_date` * `driver's license` → `driver_s_license` * `3rd category` → `_3rd_category` * `secret_id` → `secret__id`  These changes apply only to field names in the API response. The field names in the Build project are not changed.  </Info> 

        :param run_id: The run ID. (required)
        :type run_id: str
        :param include_review_results: Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> 
        :type include_review_results: bool
        :param include_confidence_scores: Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. 
        :type include_confidence_scores: bool
        :param include_validation_results: Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. 
        :type include_validation_results: bool
        :param include_source_info: Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. 
        :type include_source_info: bool
        :param file_offset: The initial file index to start returning results from. Defaults to `0`.
        :type file_offset: int
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_results_serialize(
            run_id=run_id,
            include_review_results=include_review_results,
            include_confidence_scores=include_confidence_scores,
            include_validation_results=include_validation_results,
            include_source_info=include_source_info,
            file_offset=file_offset,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResultsResponse",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_run_results_with_http_info(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        include_review_results: Annotated[Optional[StrictBool], Field(description="Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> ")] = None,
        include_confidence_scores: Annotated[Optional[StrictBool], Field(description="Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. ")] = None,
        include_validation_results: Annotated[Optional[StrictBool], Field(description="Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. ")] = None,
        include_source_info: Annotated[Optional[StrictBool], Field(description="Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. ")] = None,
        file_offset: Annotated[Optional[StrictInt], Field(description="The initial file index to start returning results from. Defaults to `0`.")] = None,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResultsResponse]:
        """Get run results

        Get the results of a completed run.  <Info>  This API operation might return field names that differ from those in the Build project.  The operation converts field names to valid Python variable names by:  * Allowing only letters, numbers, and underscores * Requiring names to start with a letter or underscore * Replacing invalid characters with underscores * Converting single underscores to double underscores  Examples: * `due date` → `due_date` * `driver's license` → `driver_s_license` * `3rd category` → `_3rd_category` * `secret_id` → `secret__id`  These changes apply only to field names in the API response. The field names in the Build project are not changed.  </Info> 

        :param run_id: The run ID. (required)
        :type run_id: str
        :param include_review_results: Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> 
        :type include_review_results: bool
        :param include_confidence_scores: Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. 
        :type include_confidence_scores: bool
        :param include_validation_results: Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. 
        :type include_validation_results: bool
        :param include_source_info: Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. 
        :type include_source_info: bool
        :param file_offset: The initial file index to start returning results from. Defaults to `0`.
        :type file_offset: int
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_results_serialize(
            run_id=run_id,
            include_review_results=include_review_results,
            include_confidence_scores=include_confidence_scores,
            include_validation_results=include_validation_results,
            include_source_info=include_source_info,
            file_offset=file_offset,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResultsResponse",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_run_results_without_preload_content(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        include_review_results: Annotated[Optional[StrictBool], Field(description="Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> ")] = None,
        include_confidence_scores: Annotated[Optional[StrictBool], Field(description="Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. ")] = None,
        include_validation_results: Annotated[Optional[StrictBool], Field(description="Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. ")] = None,
        include_source_info: Annotated[Optional[StrictBool], Field(description="Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. ")] = None,
        file_offset: Annotated[Optional[StrictInt], Field(description="The initial file index to start returning results from. Defaults to `0`.")] = None,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get run results

        Get the results of a completed run.  <Info>  This API operation might return field names that differ from those in the Build project.  The operation converts field names to valid Python variable names by:  * Allowing only letters, numbers, and underscores * Requiring names to start with a letter or underscore * Replacing invalid characters with underscores * Converting single underscores to double underscores  Examples: * `due date` → `due_date` * `driver's license` → `driver_s_license` * `3rd category` → `_3rd_category` * `secret_id` → `secret__id`  These changes apply only to field names in the API response. The field names in the Build project are not changed.  </Info> 

        :param run_id: The run ID. (required)
        :type run_id: str
        :param include_review_results: Whether to include human review details in the results. When set to `true`, details such as review status and edits at the run or document level and at the extracted field level are included.  The following values are returned at the run or document level:  - `review_completed` - `files/documents/review_completed` - `files/documents/class_edit_history` - `files/documents/class_edit_history/timestamp` - `files/documents/class_edit_history/user_id` - `files/documents/class_edit_history/modifications` - `files/documents/class_edit_history/modifications/message`  The following values are returned at the extracted field level:  - `edit_history` - `files/edit_history/timestamp` - `files/edit_history/user_id` - `files/edit_history/modifications` - `files/edit_history/modifications/message`  See the response schema for details and descriptions.  <Note>The review process can include manually correcting values. This endpoint doesn't support returning the original and corrected values.</Note> 
        :type include_review_results: bool
        :param include_confidence_scores: Whether to include confidence scores in the results. When set to `true`, classification confidence scores at the run or document level and extraction confidence scores at the extracted field level are included.  The following values are returned at the run or document level:  - `files/documents/classification_confidence/ocr`  The following values are returned at the extracted field level:  - `confidence/model`  See the response schema for details and descriptions. 
        :type include_confidence_scores: bool
        :param include_validation_results: Whether to include validation status in the results. When set to `true`, validation results at the run or document level and extracted field level are included.  The following values are returned at the run or document level:  - `files/validations/final_result_pass`  The following values are returned at the extracted field level:  - `validations/valid` - `validations/alerts`  See the response schema for details and descriptions. 
        :type include_validation_results: bool
        :param include_source_info: Whether to include source information in the results. When set to `true`, source details such as the image path of the generated image are included in the results.  The following values are returned at the run or document level:  - `files/documents/post_processed_paths`  The following values are returned at the extracted field level:  - `source_coordinates/top_x` - `source_coordinates/top_y` - `source_coordinates/bottom_x` - `source_coordinates/bottom_y` - `source_coordinates/page_number`  See the response schema for details and descriptions. 
        :type include_source_info: bool
        :param file_offset: The initial file index to start returning results from. Defaults to `0`.
        :type file_offset: int
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_results_serialize(
            run_id=run_id,
            include_review_results=include_review_results,
            include_confidence_scores=include_confidence_scores,
            include_validation_results=include_validation_results,
            include_source_info=include_source_info,
            file_offset=file_offset,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResultsResponse",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_run_results_serialize(
        self,
        run_id,
        include_review_results,
        include_confidence_scores,
        include_validation_results,
        include_source_info,
        file_offset,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        if include_review_results is not None:
            
            _query_params.append(('include_review_results', include_review_results))
            
        if include_confidence_scores is not None:
            
            _query_params.append(('include_confidence_scores', include_confidence_scores))
            
        if include_validation_results is not None:
            
            _query_params.append(('include_validation_results', include_validation_results))
            
        if include_source_info is not None:
            
            _query_params.append(('include_source_info', include_source_info))
            
        if file_offset is not None:
            
            _query_params.append(('file_offset', file_offset))
            
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/apps/runs/{run_id}/results',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_run_status(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Run:
        """Get run status

        Get the status of a run.

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_status_serialize(
            run_id=run_id,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_run_status_with_http_info(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Run]:
        """Get run status

        Get the status of a run.

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_status_serialize(
            run_id=run_id,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_run_status_without_preload_content(
        self,
        run_id: Annotated[StrictStr, Field(description="The run ID.")],
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get run status

        Get the status of a run.

        :param run_id: The run ID. (required)
        :type run_id: str
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_run_status_serialize(
            run_id=run_id,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_run_status_serialize(
        self,
        run_id,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/apps/runs/{run_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_runs(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        app_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app ID.")] = None,
        app_name: Annotated[Optional[StrictStr], Field(description="Filter runs by app name.")] = None,
        deployment_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app deployment ID.")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter runs initiated by the specified user (username).")] = None,
        run_id: Annotated[Optional[StrictStr], Field(description="Filter specific run by run ID.")] = None,
        status: Annotated[Optional[List[StrictStr]], Field(description="Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.")] = None,
        output_repo: Annotated[Optional[List[StrictStr]], Field(description="Filter runs by the output repo.")] = None,
        from_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs starting from this timestamp. Defaults to one week before the current time.")] = None,
        to_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs up to this timestamp. Defaults to the current time.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Offset of the first result to return.")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Field to sort results by.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Order of sorting, such as ASCENDING or DESCENDING.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ListRuns200Response:
        """List runs

        Return a list of runs. Use query parameters to filter results.

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param app_id: Filter runs by app ID.
        :type app_id: str
        :param app_name: Filter runs by app name.
        :type app_name: str
        :param deployment_id: Filter runs by app deployment ID.
        :type deployment_id: str
        :param username: Filter runs initiated by the specified user (username).
        :type username: str
        :param run_id: Filter specific run by run ID.
        :type run_id: str
        :param status: Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.
        :type status: List[str]
        :param output_repo: Filter runs by the output repo.
        :type output_repo: List[str]
        :param from_timestamp: Filter runs starting from this timestamp. Defaults to one week before the current time.
        :type from_timestamp: int
        :param to_timestamp: Filter runs up to this timestamp. Defaults to the current time.
        :type to_timestamp: int
        :param limit: Number of results to return.
        :type limit: int
        :param offset: Offset of the first result to return.
        :type offset: int
        :param sort_by: Field to sort results by.
        :type sort_by: str
        :param order: Order of sorting, such as ASCENDING or DESCENDING.
        :type order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_runs_serialize(
            ib_context=ib_context,
            app_id=app_id,
            app_name=app_name,
            deployment_id=deployment_id,
            username=username,
            run_id=run_id,
            status=status,
            output_repo=output_repo,
            from_timestamp=from_timestamp,
            to_timestamp=to_timestamp,
            limit=limit,
            offset=offset,
            sort_by=sort_by,
            order=order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListRuns200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_runs_with_http_info(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        app_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app ID.")] = None,
        app_name: Annotated[Optional[StrictStr], Field(description="Filter runs by app name.")] = None,
        deployment_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app deployment ID.")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter runs initiated by the specified user (username).")] = None,
        run_id: Annotated[Optional[StrictStr], Field(description="Filter specific run by run ID.")] = None,
        status: Annotated[Optional[List[StrictStr]], Field(description="Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.")] = None,
        output_repo: Annotated[Optional[List[StrictStr]], Field(description="Filter runs by the output repo.")] = None,
        from_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs starting from this timestamp. Defaults to one week before the current time.")] = None,
        to_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs up to this timestamp. Defaults to the current time.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Offset of the first result to return.")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Field to sort results by.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Order of sorting, such as ASCENDING or DESCENDING.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ListRuns200Response]:
        """List runs

        Return a list of runs. Use query parameters to filter results.

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param app_id: Filter runs by app ID.
        :type app_id: str
        :param app_name: Filter runs by app name.
        :type app_name: str
        :param deployment_id: Filter runs by app deployment ID.
        :type deployment_id: str
        :param username: Filter runs initiated by the specified user (username).
        :type username: str
        :param run_id: Filter specific run by run ID.
        :type run_id: str
        :param status: Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.
        :type status: List[str]
        :param output_repo: Filter runs by the output repo.
        :type output_repo: List[str]
        :param from_timestamp: Filter runs starting from this timestamp. Defaults to one week before the current time.
        :type from_timestamp: int
        :param to_timestamp: Filter runs up to this timestamp. Defaults to the current time.
        :type to_timestamp: int
        :param limit: Number of results to return.
        :type limit: int
        :param offset: Offset of the first result to return.
        :type offset: int
        :param sort_by: Field to sort results by.
        :type sort_by: str
        :param order: Order of sorting, such as ASCENDING or DESCENDING.
        :type order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_runs_serialize(
            ib_context=ib_context,
            app_id=app_id,
            app_name=app_name,
            deployment_id=deployment_id,
            username=username,
            run_id=run_id,
            status=status,
            output_repo=output_repo,
            from_timestamp=from_timestamp,
            to_timestamp=to_timestamp,
            limit=limit,
            offset=offset,
            sort_by=sort_by,
            order=order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListRuns200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_runs_without_preload_content(
        self,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        app_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app ID.")] = None,
        app_name: Annotated[Optional[StrictStr], Field(description="Filter runs by app name.")] = None,
        deployment_id: Annotated[Optional[StrictStr], Field(description="Filter runs by app deployment ID.")] = None,
        username: Annotated[Optional[StrictStr], Field(description="Filter runs initiated by the specified user (username).")] = None,
        run_id: Annotated[Optional[StrictStr], Field(description="Filter specific run by run ID.")] = None,
        status: Annotated[Optional[List[StrictStr]], Field(description="Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.")] = None,
        output_repo: Annotated[Optional[List[StrictStr]], Field(description="Filter runs by the output repo.")] = None,
        from_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs starting from this timestamp. Defaults to one week before the current time.")] = None,
        to_timestamp: Annotated[Optional[StrictInt], Field(description="Filter runs up to this timestamp. Defaults to the current time.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="Offset of the first result to return.")] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="Field to sort results by.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Order of sorting, such as ASCENDING or DESCENDING.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List runs

        Return a list of runs. Use query parameters to filter results.

        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param app_id: Filter runs by app ID.
        :type app_id: str
        :param app_name: Filter runs by app name.
        :type app_name: str
        :param deployment_id: Filter runs by app deployment ID.
        :type deployment_id: str
        :param username: Filter runs initiated by the specified user (username).
        :type username: str
        :param run_id: Filter specific run by run ID.
        :type run_id: str
        :param status: Filter jobs by status, such as COMPLETE, RUNNING, or FAILED.
        :type status: List[str]
        :param output_repo: Filter runs by the output repo.
        :type output_repo: List[str]
        :param from_timestamp: Filter runs starting from this timestamp. Defaults to one week before the current time.
        :type from_timestamp: int
        :param to_timestamp: Filter runs up to this timestamp. Defaults to the current time.
        :type to_timestamp: int
        :param limit: Number of results to return.
        :type limit: int
        :param offset: Offset of the first result to return.
        :type offset: int
        :param sort_by: Field to sort results by.
        :type sort_by: str
        :param order: Order of sorting, such as ASCENDING or DESCENDING.
        :type order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_runs_serialize(
            ib_context=ib_context,
            app_id=app_id,
            app_name=app_name,
            deployment_id=deployment_id,
            username=username,
            run_id=run_id,
            status=status,
            output_repo=output_repo,
            from_timestamp=from_timestamp,
            to_timestamp=to_timestamp,
            limit=limit,
            offset=offset,
            sort_by=sort_by,
            order=order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ListRuns200Response",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_runs_serialize(
        self,
        ib_context,
        app_id,
        app_name,
        deployment_id,
        username,
        run_id,
        status,
        output_repo,
        from_timestamp,
        to_timestamp,
        limit,
        offset,
        sort_by,
        order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
            'status': 'multi',
            'output_repo': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if app_id is not None:
            
            _query_params.append(('app_id', app_id))
            
        if app_name is not None:
            
            _query_params.append(('app_name', app_name))
            
        if deployment_id is not None:
            
            _query_params.append(('deployment_id', deployment_id))
            
        if username is not None:
            
            _query_params.append(('username', username))
            
        if run_id is not None:
            
            _query_params.append(('run_id', run_id))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        if output_repo is not None:
            
            _query_params.append(('output_repo', output_repo))
            
        if from_timestamp is not None:
            
            _query_params.append(('from_timestamp', from_timestamp))
            
        if to_timestamp is not None:
            
            _query_params.append(('to_timestamp', to_timestamp))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if sort_by is not None:
            
            _query_params.append(('sort_by', sort_by))
            
        if order is not None:
            
            _query_params.append(('order', order))
            
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v2/apps/runs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def run_app(
        self,
        run_app_request: RunAppRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Run:
        """Run app

        Run an app by its name or app ID. The input for the run can be a batch ID or an input file path.  To run deployments by API, use the [Run deployment endpoint.](/api-sdk/api-reference/runs/run-deployment/)  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param run_app_request: (required)
        :type run_app_request: RunAppRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_app_serialize(
            run_app_request=run_app_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def run_app_with_http_info(
        self,
        run_app_request: RunAppRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Run]:
        """Run app

        Run an app by its name or app ID. The input for the run can be a batch ID or an input file path.  To run deployments by API, use the [Run deployment endpoint.](/api-sdk/api-reference/runs/run-deployment/)  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param run_app_request: (required)
        :type run_app_request: RunAppRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_app_serialize(
            run_app_request=run_app_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def run_app_without_preload_content(
        self,
        run_app_request: RunAppRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Run app

        Run an app by its name or app ID. The input for the run can be a batch ID or an input file path.  To run deployments by API, use the [Run deployment endpoint.](/api-sdk/api-reference/runs/run-deployment/)  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param run_app_request: (required)
        :type run_app_request: RunAppRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_app_serialize(
            run_app_request=run_app_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _run_app_serialize(
        self,
        run_app_request,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter
        if run_app_request is not None:
            _body_params = run_app_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/apps/runs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def run_deployment(
        self,
        deployment_id: Annotated[StrictStr, Field(description="The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip> ")],
        run_deployment_request: RunDeploymentRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Run:
        """Run deployment

        Run an AI Hub deployment by its deployment ID. The input for the run is specified using a batch ID or file path.  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param deployment_id: The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip>  (required)
        :type deployment_id: str
        :param run_deployment_request: (required)
        :type run_deployment_request: RunDeploymentRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_deployment_serialize(
            deployment_id=deployment_id,
            run_deployment_request=run_deployment_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def run_deployment_with_http_info(
        self,
        deployment_id: Annotated[StrictStr, Field(description="The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip> ")],
        run_deployment_request: RunDeploymentRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Run]:
        """Run deployment

        Run an AI Hub deployment by its deployment ID. The input for the run is specified using a batch ID or file path.  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param deployment_id: The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip>  (required)
        :type deployment_id: str
        :param run_deployment_request: (required)
        :type run_deployment_request: RunDeploymentRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_deployment_serialize(
            deployment_id=deployment_id,
            run_deployment_request=run_deployment_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def run_deployment_without_preload_content(
        self,
        deployment_id: Annotated[StrictStr, Field(description="The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip> ")],
        run_deployment_request: RunDeploymentRequest,
        ib_context: Annotated[Optional[StrictStr], Field(description="Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Run deployment

        Run an AI Hub deployment by its deployment ID. The input for the run is specified using a batch ID or file path.  <Note>Any specified input or output is validated against the context set by the `IB-Context` header. For example, if the context is set to your community account, but the batch ID used as input for the run is stored in your organization, the call fails.</Note> 

        :param deployment_id: The deployment ID.  <Tip>You can find the deployment ID by opening the deployment in AI Hub and looking at the site URL, such as https<span>://</span>aihub.instabase.com/deployments/**01902d6f-bb35-74cb-bd27-c09b38bbf20a**/runs.</Tip>  (required)
        :type deployment_id: str
        :param run_deployment_request: (required)
        :type run_deployment_request: RunDeploymentRequest
        :param ib_context: Specify whether to use your community account or organization account to complete the request. To use your community account, define as your user ID. To use your organization account, define as your organization ID. If unspecified, defaults to community account context. See [Authorization and context identification](/api-sdk/authorization/#ib-context-header) for details.
        :type ib_context: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._run_deployment_serialize(
            deployment_id=deployment_id,
            run_deployment_request=run_deployment_request,
            ib_context=ib_context,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "Run",
            
            
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _run_deployment_serialize(
        self,
        deployment_id,
        run_deployment_request,
        ib_context,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
            
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if deployment_id is not None:
            _path_params['deployment-id'] = deployment_id
        # process the query parameters
        # process the header parameters
        if ib_context is not None:
            _header_params['IB-Context'] = ib_context
        # process the form parameters
        # process the body parameter
        if run_deployment_request is not None:
            _body_params = run_deployment_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v2/apps/deployments/{deployment-id}/runs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# flake8: noqa

# import apis into api package
from aihub.api.batches_api import BatchesApi
from aihub.api.conversations_api import ConversationsApi
from aihub.api.files_api import FilesApi
from aihub.api.jobs_api import JobsApi
from aihub.api.queries_api import QueriesApi
from aihub.api.runs_api import RunsApi

